@@ -37,12 +37,16 @@ static char THIS_FILE[]=__FILE__;
 #ifdef _WIN32
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+#include "utf8.h"
+#include <cwctype>
+
 #define OffsetType __int64
 #define MaxOffset 0x7fffffffffffffffI64
 
-DiskFile::DiskFile(std::ostream &sout, std::ostream &serr)
+DiskFile::DiskFile(std::ostream &sout, std::ostream &serr, std::mutex &serr_lock)
 : sout(&sout)
 , serr(&serr)
+, serr_lock(&serr_lock)
 {
   filename = "";
   filesize = 0;
@@ -60,27 +64,38 @@ DiskFile::~DiskFile(void)
     ::CloseHandle(hFile);
 }
 
-bool DiskFile::CreateParentDirectory(string _pathname)
+bool DiskFile::CreateParentDirectory(std::string _pathname)
 {
   // do we have a path separator in the filename ?
-  string::size_type where;
-  if (string::npos != (where = _pathname.find_last_of('/')) ||
-      string::npos != (where = _pathname.find_last_of('\\')))
+  std::string::size_type where;
+  if (std::string::npos != (where = _pathname.find_last_of(PATHSEP)) ||
+      std::string::npos != (where = _pathname.find_last_of(ALTPATHSEP)))
   {
-    string path = filename.substr(0, where);
+    std::string path = _pathname.substr(0, where);
 
-    struct stat st;
-    if (stat(path.c_str(), &st) == 0)
+    // Handle Windows root path (e.g., "C:" or empty path from "\file")
+    // If path is empty or is a drive letter (e.g., "C:"), the root already exists
+    if (path.empty() ||
+        (path.length() == 2 && path[1] == ':'))
+    {
+      return true;
+    }
+
+    std::wstring wpath = utf8::Utf8ToWide(path);
+
+    struct _stati64 st;
+    if (_wstati64(wpath.c_str(), &st) == 0)
       return true; // let the caller deal with non-directories
 
     if (!DiskFile::CreateParentDirectory(path))
       return false;
 
-    if (!CreateDirectory(path.c_str(), NULL))
+    if (!CreateDirectoryW(wpath.c_str(), NULL))
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not create the " << path << " directory: " << ErrorMessage(error) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not create the " << path << " directory: " << ErrorMessage(error) << std::endl;
 
       return false;
     }
@@ -90,7 +105,7 @@ bool DiskFile::CreateParentDirectory(string _pathname)
 
 // Create new file on disk and make sure that there is enough
 // space on disk for it.
-bool DiskFile::Create(string _filename, u64 _filesize)
+bool DiskFile::Create(std::string _filename, u64 _filesize)
 {
   assert(hFile == INVALID_HANDLE_VALUE);
 
@@ -101,12 +116,14 @@ bool DiskFile::Create(string _filename, u64 _filesize)
     return false;
 
   // Create the file
-  hFile = ::CreateFileA(_filename.c_str(), GENERIC_READ | GENERIC_WRITE, 0, NULL, CREATE_NEW, 0, NULL);
+  std::wstring wfilename = utf8::Utf8ToWide(_filename);
+  hFile = ::CreateFileW(wfilename.c_str(), GENERIC_READ | GENERIC_WRITE, 0, NULL, CREATE_NEW, 0, NULL);
   if (hFile == INVALID_HANDLE_VALUE)
   {
     DWORD error = ::GetLastError();
 
-    *serr << "Could not create \"" << _filename << "\": " << ErrorMessage(error) << endl;
+    std::lock_guard<std::mutex> lock(*serr_lock);
+    *serr << "Could not create \"" << _filename << "\": " << ErrorMessage(error) << std::endl;
 
     return false;
   }
@@ -122,11 +139,14 @@ bool DiskFile::Create(string _filename, u64 _filesize)
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not set size of \"" << _filename << "\": " << ErrorMessage(error) << endl;
+      {
+        std::lock_guard<std::mutex> lock(*serr_lock);
+        *serr << "Could not set size of \"" << _filename << "\": " << ErrorMessage(error) << std::endl;
+      }
 
       ::CloseHandle(hFile);
       hFile = INVALID_HANDLE_VALUE;
-      ::DeleteFile(_filename.c_str());
+      ::DeleteFileW(wfilename.c_str());
 
       return false;
     }
@@ -136,11 +156,14 @@ bool DiskFile::Create(string _filename, u64 _filesize)
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not set size of \"" << _filename << "\": " << ErrorMessage(error) << endl;
+      {
+        std::lock_guard<std::mutex> lock(*serr_lock);
+        *serr << "Could not set size of \"" << _filename << "\": " << ErrorMessage(error) << std::endl;
+      }
 
       ::CloseHandle(hFile);
       hFile = INVALID_HANDLE_VALUE;
-      ::DeleteFile(_filename.c_str());
+      ::DeleteFileW(wfilename.c_str());
 
       return false;
     }
@@ -169,7 +192,8 @@ bool DiskFile::Write(u64 _offset, const void *buffer, size_t length, LengthType
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not write " << (u64)length << " bytes to \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not write " << (u64)length << " bytes to \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << std::endl;
 
       return false;
     }
@@ -191,14 +215,16 @@ bool DiskFile::Write(u64 _offset, const void *buffer, size_t length, LengthType
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not write " << write << " bytes to \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not write " << write << " bytes to \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << std::endl;
 
       return false;
     }
 
     if (wrote != write)
     {
-      *serr << "INFO: Incomplete write to \"" << filename << "\" at offset " << _offset << ".  Expected to write " << write << " bytes and wrote " << wrote << " bytes." << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "INFO: Incomplete write to \"" << filename << "\" at offset " << _offset << ".  Expected to write " << write << " bytes and wrote " << wrote << " bytes." << std::endl;
     }
 
     offset += wrote;
@@ -216,14 +242,15 @@ bool DiskFile::Write(u64 _offset, const void *buffer, size_t length, LengthType
 
 // Open the file
 
-bool DiskFile::Open(const string &_filename, u64 _filesize)
+bool DiskFile::Open(const std::string &_filename, u64 _filesize)
 {
   assert(hFile == INVALID_HANDLE_VALUE);
 
   filename = _filename;
   filesize = _filesize;
 
-  hFile = ::CreateFileA(_filename.c_str(), GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL);
+  std::wstring wfilename = utf8::Utf8ToWide(_filename);
+  hFile = ::CreateFileW(wfilename.c_str(), GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL);
   if (hFile == INVALID_HANDLE_VALUE)
   {
     DWORD error = ::GetLastError();
@@ -234,7 +261,8 @@ bool DiskFile::Open(const string &_filename, u64 _filesize)
     case ERROR_PATH_NOT_FOUND:
       break;
     default:
-      *serr << "Could not open \"" << _filename << "\": " << ErrorMessage(error) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not open \"" << _filename << "\": " << ErrorMessage(error) << std::endl;
     }
 
     return false;
@@ -263,7 +291,8 @@ bool DiskFile::Read(u64 _offset, void *buffer, size_t length, LengthType maxleng
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not read " << (u64)length << " bytes from \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not read " << (u64)length << " bytes from \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << std::endl;
 
       return false;
     }
@@ -284,14 +313,16 @@ bool DiskFile::Read(u64 _offset, void *buffer, size_t length, LengthType maxleng
     {
       DWORD error = ::GetLastError();
 
-      *serr << "Could not read " << (u64)length << " bytes from \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not read " << (u64)length << " bytes from \"" << filename << "\" at offset " << _offset << ": " << ErrorMessage(error) << std::endl;
 
       return false;
     }
 
     if (want != got)
     {
-      *serr << "Incomplete read from \"" << filename << "\" at offset " << offset << ".  Tried to read " << want << " bytes and received " << got << " bytes." << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Incomplete read from \"" << filename << "\" at offset " << offset << ".  Tried to read " << want << " bytes and received " << got << " bytes." << std::endl;
     }
 
     offset += got;
@@ -313,114 +344,80 @@ void DiskFile::Close(void)
   }
 }
 
-string DiskFile::GetCanonicalPathname(string filename)
+std::string DiskFile::GetCanonicalPathname(std::string filename)
 {
-  char fullname[MAX_PATH];
-  char *filepart;
+  std::wstring wfilename = utf8::Utf8ToWide(filename);
 
-  // Resolve a relative path to a full path
-  unsigned int length = ::GetFullPathName(filename.c_str(), sizeof(fullname), fullname, &filepart);
-  if (length <= 0 || sizeof(fullname) < length)
+  // First call to get required buffer size
+  DWORD length = GetFullPathNameW(wfilename.c_str(), 0, nullptr, nullptr);
+  if (length == 0) 
+  {
+    return filename; 
+  }
+
+  // Allocate buffer with required size
+  auto wfullname = std::make_unique<wchar_t[]>(length);
+
+  // Second call to get the actual path
+  length = GetFullPathNameW(wfilename.c_str(), length, wfullname.get(), nullptr);
+  if (length == 0)
+  {
     return filename;
-
-  // Make sure the drive letter is upper case.
-  fullname[0] = toupper(fullname[0]);
-
-  // Translate all /'s to \'s
-  char *current = strchr(fullname, '/');
-  while (current)
-  {
-    *current++ = '\\';
-    current  = strchr(current, '/');
   }
 
-  // Copy the root directory to the output string
-  string longname(fullname, 3);
+  wfullname[0] = towupper(wfullname[0]);
+  std::replace(wfullname.get(), wfullname.get() + length, L'/', L'\\');
 
-  // Start processing at the first path component
-  current = &fullname[3];
-  char *limit = &fullname[length];
-
-  // Process until we reach the end of the full name
-  while (current < limit)
-  {
-    char *tail;
-
-    // Find the next \, or the end of the string
-    (tail = strchr(current, '\\')) || (tail = limit);
-    *tail = 0;
-
-    // Create a wildcard to search for the path
-    string wild = longname + current;
-    WIN32_FIND_DATA finddata;
-    HANDLE hFind = ::FindFirstFile(wild.c_str(), &finddata);
-    if (hFind == INVALID_HANDLE_VALUE)
-    {
-      // If the component was not found then just copy the rest of the path to the
-      // output buffer verbatim.
-      longname += current;
-      break;
-    }
-    ::FindClose(hFind);
-
-    // Copy the component found to the output
-    longname += finddata.cFileName;
-
-    current = tail + 1;
-
-    // If we have not reached the end of the name, add a "\"
-    if (current < limit)
-      longname += '\\';
-  }
-
-  return longname;
+  return utf8::WideToUtf8(wfullname.get());
 }
 
-std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard, bool recursive)
+std::unique_ptr< std::list<std::string> > DiskFile::FindFiles(std::string path, std::string wildcard, bool recursive)
 {
   // check path, if not ending with path separator, add one
   char pathend = *path.rbegin();
-  if (pathend != '\\')
+  if (pathend != PATHSEP[0])
   {
-    path += '\\';
+    path += PATHSEP;
   }
-  list<string> *matches = new list<string>;
+  std::list<std::string> *matches = new std::list<std::string>;
 
-  wildcard = path + wildcard;
-  WIN32_FIND_DATA fd;
-  HANDLE h = ::FindFirstFile(wildcard.c_str(), &fd);
+  std::wstring wwildcard = utf8::Utf8ToWide(path + wildcard);
+  WIN32_FIND_DATAW fd;
+  HANDLE h = ::FindFirstFileW(wwildcard.c_str(), &fd);
   if (h != INVALID_HANDLE_VALUE)
   {
     do
     {
       if (0 == (fd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
       {
-        matches->push_back(path + fd.cFileName);
+        matches->push_back(path + utf8::WideToUtf8(fd.cFileName));
       }
-      else if (fd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
+      else if (recursive == true)
       {
         if (fd.cFileName[0] == '.') {
           continue;
         }
 
-        string nwwildcard="*";
-	std::unique_ptr< list<string> > dirmatches(
-						 DiskFile::FindFiles(path + fd.cFileName, nwwildcard, true)
+        std::string nwwildcard="*";
+	std::unique_ptr< std::list<std::string> > dirmatches(
+						 DiskFile::FindFiles(path + utf8::WideToUtf8(fd.cFileName), nwwildcard, true)
 						 );
 
-        matches->merge(*dirmatches);
+        // append without requiring ordering
+        matches->splice(matches->end(), *dirmatches);
       }
-    } while (::FindNextFile(h, &fd));
+    } while (::FindNextFileW(h, &fd));
     ::FindClose(h);
   }
 
-  return std::unique_ptr< list<string> >(matches);
+  return std::unique_ptr< std::list<std::string> >(matches);
 }
 
-u64 DiskFile::GetFileSize(string filename)
+u64 DiskFile::GetFileSize(std::string filename)
 {
+  std::wstring wfilename = utf8::Utf8ToWide(filename);
   struct _stati64 st;
-  if ((0 == _stati64(filename.c_str(), &st)) && (0 != (st.st_mode & S_IFREG)))
+  if ((0 == _wstati64(wfilename.c_str(), &st)) && (0 != (st.st_mode & S_IFREG)))
   {
     return st.st_size;
   }
@@ -430,10 +427,11 @@ u64 DiskFile::GetFileSize(string filename)
   }
 }
 
-bool DiskFile::FileExists(string filename)
+bool DiskFile::FileExists(std::string filename)
 {
+  std::wstring wfilename = utf8::Utf8ToWide(filename);
   struct _stati64 st;
-  return ((0 == _stati64(filename.c_str(), &st)) && (0 != (st.st_mode & S_IFREG)));
+  return ((0 == _wstati64(wfilename.c_str(), &st)) && (0 != (st.st_mode & _S_IFREG))); 
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -455,9 +453,10 @@ bool DiskFile::FileExists(string filename)
 #endif
 
 
-DiskFile::DiskFile(std::ostream &sout, std::ostream &serr)
+DiskFile::DiskFile(std::ostream &sout, std::ostream &serr, std::mutex &serr_lock)
 : sout(&sout)
 , serr(&serr)
+, serr_lock(&serr_lock)
 {
   //filename;
   filesize = 0;
@@ -475,14 +474,20 @@ DiskFile::~DiskFile(void)
     fclose(file);
 }
 
-bool DiskFile::CreateParentDirectory(string _pathname)
+bool DiskFile::CreateParentDirectory(std::string _pathname)
 {
   // do we have a path separator in the filename ?
-  string::size_type where;
-  if (string::npos != (where = _pathname.find_last_of('/')) ||
-      string::npos != (where = _pathname.find_last_of('\\')))
+  std::string::size_type where;
+  if (std::string::npos != (where = _pathname.find_last_of(PATHSEP)) ||
+      std::string::npos != (where = _pathname.find_last_of(ALTPATHSEP)))
   {
-    string path = filename.substr(0, where);
+    std::string path = _pathname.substr(0, where);
+
+    // Handle root path - if path is empty, the root already exists
+    if (path.empty())
+    {
+      return true;
+    }
 
     struct stat st;
     if (stat(path.c_str(), &st) == 0)
@@ -493,7 +498,8 @@ bool DiskFile::CreateParentDirectory(string _pathname)
 
     if (mkdir(path.c_str(), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH))
     {
-      *serr << "Could not create the " << path << " directory: " << strerror(errno) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not create the " << path << " directory: " << strerror(errno) << std::endl;
       return false;
     }
   }
@@ -502,7 +508,7 @@ bool DiskFile::CreateParentDirectory(string _pathname)
 
 // Create new file on disk and make sure that there is enough
 // space on disk for it.
-bool DiskFile::Create(string _filename, u64 _filesize)
+bool DiskFile::Create(std::string _filename, u64 _filesize)
 {
   assert(file == 0);
 
@@ -516,21 +522,24 @@ bool DiskFile::Create(string _filename, u64 _filesize)
   // the Windows code would error out after too.
   if (FileExists(filename))
   {
-    *serr << "Could not create \"" << _filename << "\": File already exists." << endl;
+    std::lock_guard<std::mutex> lock(*serr_lock);
+    *serr << "Could not create \"" << _filename << "\": File already exists." << std::endl;
     return false;
   }
 
   file = fopen(_filename.c_str(), "wb");
   if (file == 0)
   {
-    *serr << "Could not create " << _filename << ": " << strerror(errno) << endl;
+    std::lock_guard<std::mutex> lock(*serr_lock);
+    *serr << "Could not create " << _filename << ": " << strerror(errno) << std::endl;
 
     return false;
   }
 
   if (_filesize > (u64)MaxOffset)
   {
-    *serr << "Requested file size for " << _filename << " is too large." << endl;
+    std::lock_guard<std::mutex> lock(*serr_lock);
+    *serr << "Requested file size for " << _filename << " is too large." << std::endl;
     return false;
   }
 
@@ -538,7 +547,10 @@ bool DiskFile::Create(string _filename, u64 _filesize)
   {
     if (fseek(file, (OffsetType)_filesize-1, SEEK_SET))
     {
-      *serr << "Could not set end of file of " << _filename << ": " << strerror(errno) << endl;
+      {
+        std::lock_guard<std::mutex> lock(*serr_lock);
+        *serr << "Could not set end of file of " << _filename << ": " << strerror(errno) << std::endl;
+      }
 
       fclose(file);
       file = 0;
@@ -548,7 +560,10 @@ bool DiskFile::Create(string _filename, u64 _filesize)
 
     if (1 != fwrite(&_filesize, 1, 1, file))
     {
-      *serr << "Could not set end of file of " << _filename << ": " << strerror(errno) << endl;
+      {
+        std::lock_guard<std::mutex> lock(*serr_lock);
+        *serr << "Could not set end of file of " << _filename << ": " << strerror(errno) << std::endl;
+      }
 
       fclose(file);
       file = 0;
@@ -573,14 +588,16 @@ bool DiskFile::Write(u64 _offset, const void *buffer, size_t length, LengthType
   {
     if (_offset > (u64)MaxOffset)
     {
-        *serr << "Could not write " << (u64)length << " bytes to " << filename << " at offset " << _offset << endl;
+        std::lock_guard<std::mutex> lock(*serr_lock);
+        *serr << "Could not write " << (u64)length << " bytes to " << filename << " at offset " << _offset << std::endl;
       return false;
     }
 
 
     if (fseek(file, (OffsetType)_offset, SEEK_SET))
     {
-      *serr << "Could not write " << (u64)length << " bytes to " << filename << " at offset " << _offset << ": " << strerror(errno) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not write " << (u64)length << " bytes to " << filename << " at offset " << _offset << ": " << strerror(errno) << std::endl;
       return false;
     }
     offset = _offset;
@@ -597,7 +614,8 @@ bool DiskFile::Write(u64 _offset, const void *buffer, size_t length, LengthType
     LengthType wrote = fwrite(buffer, 1, write, file);
     if (wrote != write)
     {
-      *serr << "Could not write " << (u64)length << " bytes to " << filename << " at offset " << _offset << ": " << strerror(errno) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not write " << (u64)length << " bytes to " << filename << " at offset " << _offset << ": " << strerror(errno) << std::endl;
       return false;
     }
 
@@ -616,7 +634,7 @@ bool DiskFile::Write(u64 _offset, const void *buffer, size_t length, LengthType
 
 // Open the file
 
-bool DiskFile::Open(const string &_filename, u64 _filesize)
+bool DiskFile::Open(const std::string &_filename, u64 _filesize)
 {
   assert(file == 0);
 
@@ -625,7 +643,8 @@ bool DiskFile::Open(const string &_filename, u64 _filesize)
 
   if (_filesize > (u64)MaxOffset)
   {
-    *serr << "File size for " << _filename << " is too large." << endl;
+    std::lock_guard<std::mutex> lock(*serr_lock);
+    *serr << "File size for " << _filename << " is too large." << std::endl;
     return false;
   }
 
@@ -651,14 +670,16 @@ bool DiskFile::Read(u64 _offset, void *buffer, size_t length, LengthType maxleng
   {
     if (_offset > (u64)MaxOffset)
     {
-      *serr << "Could not read " << (u64)length << " bytes from " << filename << " at offset " << _offset << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not read " << (u64)length << " bytes from " << filename << " at offset " << _offset << std::endl;
       return false;
     }
 
 
     if (fseek(file, (OffsetType)_offset, SEEK_SET))
     {
-      *serr << "Could not read " << (u64)length << " bytes from " << filename << " at offset " << _offset << ": " << strerror(errno) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not read " << (u64)length << " bytes from " << filename << " at offset " << _offset << ": " << strerror(errno) << std::endl;
       return false;
     }
     offset = _offset;
@@ -678,7 +699,8 @@ bool DiskFile::Read(u64 _offset, void *buffer, size_t length, LengthType maxleng
     {
       // NOTE: This can happen on error or when hitting the end-of-file.
 
-      *serr << "Could not read " << (u64)length << " bytes from " << filename << " at offset " << _offset << ": " << strerror(errno) << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << "Could not read " << (u64)length << " bytes from " << filename << " at offset " << _offset << ": " << strerror(errno) << std::endl;
       return false;
     }
 
@@ -702,7 +724,7 @@ void DiskFile::Close(void)
 }
 
 // Attempt to get the full pathname of the file
-string DiskFile::GetCanonicalPathname(string filename)
+std::string DiskFile::GetCanonicalPathname(std::string filename)
 {
   // Is the supplied path already an absolute one
   if (filename.size() == 0 || filename[0] == '/')
@@ -768,13 +790,13 @@ string DiskFile::GetCanonicalPathname(string filename)
   }
   *out = 0;
 
-  string result = work;
+  std::string result = work;
   delete [] work;
 
   return result;
 }
 
-std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard, bool recursive)
+std::unique_ptr< std::list<std::string> > DiskFile::FindFiles(std::string path, std::string wildcard, bool recursive)
 {
   // check path, if not ending with path separator, add one
   char pathend = *path.rbegin();
@@ -782,16 +804,16 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
   {
     path += '/';
   }
-  list<string> *matches = new list<string>;
+  std::list<std::string> *matches = new std::list<std::string>;
 
-  string::size_type where;
+  std::string::size_type where;
 
-  if ((where = wildcard.find_first_of('*')) != string::npos ||
-      (where = wildcard.find_first_of('?')) != string::npos)
+  if ((where = wildcard.find_first_of('*')) != std::string::npos ||
+      (where = wildcard.find_first_of('?')) != std::string::npos)
   {
-    string front = wildcard.substr(0, where);
+    std::string front = wildcard.substr(0, where);
     bool multiple = wildcard[where] == '*';
-    string back = wildcard.substr(where+1);
+    std::string back = wildcard.substr(where+1);
 
     DIR *dirp = opendir(path.c_str());
     if (dirp != 0)
@@ -799,7 +821,7 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
       struct dirent *d;
       while ((d = readdir(dirp)) != 0)
       {
-        string name = d->d_name;
+        std::string name = d->d_name;
 
         if (name == "." || name == "..")
           continue;
@@ -811,18 +833,18 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
               name.substr(name.size()-back.size()) == back)
           {
             struct stat st;
-            string fn = path + name;
-            if (stat(fn.c_str(), &st) == 0)
+            std::string fn = path + name;
+            if (lstat(fn.c_str(), &st) == 0)
             {
               if (S_ISDIR(st.st_mode) &&
                   recursive == true)
               {
 
-                string nwwildcard="*";
-                std::unique_ptr< list<string> > dirmatches(
+                std::string nwwildcard="*";
+                std::unique_ptr< std::list<std::string> > dirmatches(
 							 DiskFile::FindFiles(fn, nwwildcard, true)
 							 );
-                matches->merge(*dirmatches);
+                matches->splice(matches->end(), *dirmatches);
               }
               else if (S_ISREG(st.st_mode))
               {
@@ -835,8 +857,8 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
         {
           if (name.size() == wildcard.size())
           {
-            string::const_iterator pw = wildcard.begin();
-            string::const_iterator pn = name.begin();
+            std::string::const_iterator pw = wildcard.begin();
+            std::string::const_iterator pn = name.begin();
             while (pw != wildcard.end())
             {
               if (*pw != '?' && *pw != *pn)
@@ -848,19 +870,19 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
             if (pw == wildcard.end())
             {
               struct stat st;
-              string fn = path + name;
-              if (stat(fn.c_str(), &st) == 0)
+              std::string fn = path + name;
+              if (lstat(fn.c_str(), &st) == 0)
               {
                 if (S_ISDIR(st.st_mode) &&
                     recursive == true)
                 {
 
-                  string nwwildcard="*";
-		  std::unique_ptr< list<string> > dirmatches(
+                  std::string nwwildcard="*";
+		  std::unique_ptr< std::list<std::string> > dirmatches(
 							   DiskFile::FindFiles(fn, nwwildcard, true)
 							   );
 
-                  matches->merge(*dirmatches);
+                  matches->splice(matches->end(), *dirmatches);
                 }
                 else if (S_ISREG(st.st_mode))
                 {
@@ -878,18 +900,18 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
   else
   {
     struct stat st;
-    string fn = path + wildcard;
-    if (stat(fn.c_str(), &st) == 0)
+    std::string fn = path + wildcard;
+    if (lstat(fn.c_str(), &st) == 0)
     {
       if (S_ISDIR(st.st_mode) &&
           recursive == true)
       {
-        string nwwildcard="*";
-	std::unique_ptr< list<string> > dirmatches(
+        std::string nwwildcard="*";
+	std::unique_ptr< std::list<std::string> > dirmatches(
 						 DiskFile::FindFiles(fn, nwwildcard, true)
 						 );
 
-        matches->merge(*dirmatches);
+        matches->splice(matches->end(), *dirmatches);
       }
       else if (S_ISREG(st.st_mode))
       {
@@ -898,10 +920,10 @@ std::unique_ptr< list<string> > DiskFile::FindFiles(string path, string wildcard
     }
   }
 
-  return std::unique_ptr< list<string> >(matches);
+  return std::unique_ptr< std::list<std::string> >(matches);
 }
 
-u64 DiskFile::GetFileSize(string filename)
+u64 DiskFile::GetFileSize(std::string filename)
 {
   struct stat st;
   if ((0 == stat(filename.c_str(), &st)) && (0 != (st.st_mode & S_IFREG)))
@@ -914,7 +936,7 @@ u64 DiskFile::GetFileSize(string filename)
   }
 }
 
-bool DiskFile::FileExists(string filename)
+bool DiskFile::FileExists(std::string filename)
 {
   struct stat st;
   return ((0 == stat(filename.c_str(), &st)) && (0 != (st.st_mode & S_IFREG)));
@@ -924,12 +946,12 @@ bool DiskFile::FileExists(string filename)
 
 bool DiskFile::Open(void)
 {
-  string _filename = filename;
+  std::string _filename = filename;
 
   return Open(_filename);
 }
 
-bool DiskFile::Open(const string &_filename)
+bool DiskFile::Open(const std::string &_filename)
 {
   return Open(_filename, GetFileSize(_filename));
 }
@@ -940,29 +962,37 @@ bool DiskFile::Delete(void)
 {
 #ifdef _WIN32
   assert(hFile == INVALID_HANDLE_VALUE);
+
+  std::wstring wfilename = utf8::Utf8ToWide(filename);
+  if (filename.size() > 0 && ::DeleteFileW(wfilename.c_str()))
+  {
+    exists = false;
+    return true;
+  }
 #else
   assert(file == 0);
-#endif
 
   if (filename.size() > 0 && 0 == unlink(filename.c_str()))
   {
     exists = false;
     return true;
   }
+#endif
   else
   {
-    *serr << "Cannot delete " << filename << endl;
+    std::lock_guard<std::mutex> lock(*serr_lock);
+    *serr << "Cannot delete " << filename << std::endl;
 
     return false;
   }
 }
 
-//string DiskFile::GetPathFromFilename(string filename)
+//std::string DiskFile::GetPathFromFilename(std::string filename)
 //{
-//  string::size_type where;
+//  std::string::size_type where;
 //
-//  if (string::npos != (where = filename.find_last_of('/')) ||
-//      string::npos != (where = filename.find_last_of('\\')))
+//  if (std::string::npos != (where = filename.find_last_of('/')) ||
+//      std::string::npos != (where = filename.find_last_of('\\')))
 //  {
 //    return filename.substr(0, where+1);
 //  }
@@ -972,12 +1002,12 @@ bool DiskFile::Delete(void)
 //  }
 //}
 
-void DiskFile::SplitFilename(string filename, string &path, string &name)
+void DiskFile::SplitFilename(std::string filename, std::string &path, std::string &name)
 {
-  string::size_type where;
+  std::string::size_type where;
 
-  if (string::npos != (where = filename.find_last_of('/')) ||
-      string::npos != (where = filename.find_last_of('\\')))
+  if (std::string::npos != (where = filename.find_last_of(PATHSEP)) ||
+      std::string::npos != (where = filename.find_last_of(ALTPATHSEP)))
   {
     path = filename.substr(0, where+1);
     name = filename.substr(where+1);
@@ -989,75 +1019,80 @@ void DiskFile::SplitFilename(string filename, string &path, string &name)
   }
 }
 
-void DiskFile::SplitRelativeFilename(string filename, string basepath, string &name)
+void DiskFile::SplitRelativeFilename(std::string filename, std::string basepath, std::string &name)
 {
   name = filename;
   name.erase(0, basepath.length());
 }
 
+#ifdef _WIN32
 bool DiskFile::Rename(void)
 {
-  char newname[_MAX_PATH+1];
   u32 index = 0;
+  std::string newname;
+  std::wstring wnewname;
+  struct _stati64 st;
 
+  do
+  {
+    // Build the new filename with index suffix
+    newname = filename + "." + std::to_string(++index);
+
+    // Check path length against maximum
+    if (newname.length() > _MAX_PATH)
+    {
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << filename << " pathlength is more than " << _MAX_PATH << "." << std::endl;
+      return false;
+    }
+
+    wnewname = utf8::Utf8ToWide(newname);
+
+    // Check if file exists using wide-character stat
+  } while (_wstati64(wnewname.c_str(), &st) == 0);
+
+  return Rename(newname);
+}
+#else
+bool DiskFile::Rename(void)
+{
+  u32 index = 0;
+  std::string newname;
   struct stat st;
 
   do
   {
-    int length = snprintf(newname, _MAX_PATH, "%s.%u", filename.c_str(), (unsigned int) ++index);
-    if (length < 0)
+    // Build the new filename with index suffix
+    newname = filename + "." + std::to_string(++index);
+
+    // Check path length against maximum
+    if (newname.length() > _MAX_PATH)
     {
-      *serr << filename << " cannot be renamed." << endl;
+      std::lock_guard<std::mutex> lock(*serr_lock);
+      *serr << filename << " pathlength is more than " << _MAX_PATH << "." << std::endl;
       return false;
     }
-    else if (length > _MAX_PATH)
-    {
-      *serr << filename << " pathlength is more than " << _MAX_PATH << "." << endl;
-      return false;
-    }
-    newname[length] = 0;
-  } while (stat(newname, &st) == 0);
+  } while (stat(newname.c_str(), &st) == 0);
 
   return Rename(newname);
 }
-
-bool DiskFile::Rename(string _filename)
-{
-#ifdef _WIN32
-  assert(hFile == INVALID_HANDLE_VALUE);
-#else
-  assert(file == 0);
 #endif
 
-  if (::rename(filename.c_str(), _filename.c_str()) == 0)
-  {
-    filename = _filename;
-
-    return true;
-  }
-  else
-  {
-    *serr << filename << " cannot be renamed to " << _filename << endl;
-
-    return false;
-  }
-}
-
 #ifdef _WIN32
-string DiskFile::ErrorMessage(DWORD error)
+std::string DiskFile::ErrorMessage(DWORD error)
 {
-  string result;
+  std::string result;
 
   LPVOID lpMsgBuf;
-  if (::FormatMessageA(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
+  if (::FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
                        NULL,
                        error,
                        MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-                       (LPSTR)&lpMsgBuf,
+                       (LPWSTR)&lpMsgBuf,
                        0,
                        NULL))
   {
-    result = (char*)lpMsgBuf;
+    result = utf8::WideToUtf8((wchar_t*)lpMsgBuf);
     LocalFree(lpMsgBuf);
   }
   else
@@ -1069,6 +1104,43 @@ string DiskFile::ErrorMessage(DWORD error)
 
   return result;
 }
+
+bool DiskFile::Rename(std::string _filename)
+{
+  assert(hFile == INVALID_HANDLE_VALUE);
+
+  std::wstring wfilename = utf8::Utf8ToWide(filename);
+  std::wstring _wfilename = utf8::Utf8ToWide(_filename);
+
+  if (::MoveFileW(wfilename.c_str(), _wfilename.c_str()))
+  {
+    filename.swap(_filename);
+
+    return true;
+  }
+
+  std::lock_guard<std::mutex> lock(*serr_lock);
+  *serr << filename << " cannot be renamed to " << _filename << std::endl;
+
+  return false;
+}
+#else
+bool DiskFile::Rename(std::string _filename)
+{
+  assert(file == 0);
+
+  if (::rename(filename.c_str(), _filename.c_str()) == 0)
+  {
+    filename.swap(_filename);
+
+    return true;
+  }
+
+  std::lock_guard<std::mutex> lock(*serr_lock);
+  *serr << filename << " cannot be renamed to " << _filename << std::endl;
+
+  return false;
+}
 #endif
 
 DiskFileMap::DiskFileMap(void)
@@ -1077,7 +1149,7 @@ DiskFileMap::DiskFileMap(void)
 
 DiskFileMap::~DiskFileMap(void)
 {
-  map<string, DiskFile*>::iterator fi = diskfilemap.begin();
+  std::map<std::string, DiskFile*>::iterator fi = diskfilemap.begin();
   while (fi != diskfilemap.end())
   {
     delete (*fi).second;
@@ -1088,27 +1160,27 @@ DiskFileMap::~DiskFileMap(void)
 
 bool DiskFileMap::Insert(DiskFile *diskfile)
 {
-  string filename = diskfile->FileName();
+  std::string filename = diskfile->FileName();
   assert(filename.length() != 0);
 
-  pair<map<string,DiskFile*>::const_iterator,bool> location = diskfilemap.insert(pair<string,DiskFile*>(filename, diskfile));
+  std::pair<std::map<std::string,DiskFile*>::const_iterator,bool> location = diskfilemap.insert(std::pair<std::string,DiskFile*>(filename, diskfile));
 
   return location.second;
 }
 
 void DiskFileMap::Remove(DiskFile *diskfile)
 {
-  string filename = diskfile->FileName();
+  std::string filename = diskfile->FileName();
   assert(filename.length() != 0);
 
   diskfilemap.erase(filename);
 }
 
-DiskFile* DiskFileMap::Find(string filename) const
+DiskFile* DiskFileMap::Find(std::string filename) const
 {
   assert(filename.length() != 0);
 
-  map<string, DiskFile*>::const_iterator f = diskfilemap.find(filename);
+  std::map<std::string, DiskFile*>::const_iterator f = diskfilemap.find(filename);
 
   return (f != diskfilemap.end()) ?  f->second : 0;
 }
@@ -1118,16 +1190,16 @@ FileSizeCache::FileSizeCache()
 {
 }
 
-u64 FileSizeCache::get(const string &filename) {
-  map<string, u64>::const_iterator f = cache.find(filename);
+u64 FileSizeCache::get(const std::string &filename) {
+  std::map<std::string, u64>::const_iterator f = cache.find(filename);
   if (f != cache.end())
     return f->second;
 
   // go to disk
   u64 filesize = DiskFile::GetFileSize(filename);
 
-  cache.insert(pair<string,u64>(filename, filesize));
-  //  pair<map<string,u64>::const_iterator,bool> location = cache.insert(pair<string,u64>(filename, filesize));
+  cache.insert(std::pair<std::string,u64>(filename, filesize));
+  //  std::pair<std::map<std::string,u64>::const_iterator,bool> location = cache.insert(std::pair<std::string,u64>(filename, filesize));
   //  if (!location.second) {
   //    throw exception?
   //  }
