@@ -46,7 +46,9 @@ int main(int argc, char* argv[])
 #ifdef _MSC_VER
   // Memory leak checking
   _CrtSetDbgFlag(_CrtSetDbgFlag(_CRTDBG_REPORT_FLAG) | _CRTDBG_ALLOC_MEM_DF | /*_CRTDBG_CHECK_CRT_DF | */_CRTDBG_DELAY_FREE_MEM_DF | _CRTDBG_LEAK_CHECK_DF);
+#endif
 
+#ifdef _WIN32
   SetConsoleOutputCP(CP_UTF8);
 
   utf8::WideToUtf8ArgsAdapter wargsAdapter{ argc, wargv };
@@ -54,10 +56,10 @@ int main(int argc, char* argv[])
 #endif
 
   // check sizeof integers
-  static_assert(sizeof(u8) == 1 || sizeof(i8) == 1
-		|| sizeof(u16) == 2 || sizeof(i16) == 1
-		|| sizeof(u32) == 4 || sizeof(i32) == 1
-		|| sizeof(u64) == 8 || sizeof(i64) == 1,
+  static_assert(sizeof(u8) == 1 && sizeof(i8) == 1
+		&& sizeof(u16) == 2 && sizeof(i16) == 2
+		&& sizeof(u32) == 4 && sizeof(i32) == 4
+		&& sizeof(u64) == 8 && sizeof(i64) == 8,
 		"Error: the assumed sizes of integers is wrong!");
 
 
@@ -122,6 +124,7 @@ int main(int argc, char* argv[])
 				  commandline->GetExtraFiles(),
 				  commandline->GetOperation() == CommandLine::opRepair,
 				  commandline->GetPurgeFiles(),
+				  commandline->GetRenameOnly(),
 				  commandline->GetSkipData(),
 				  commandline->GetSkipLeaway());
               break;
