@@ -78,7 +78,7 @@ Par2Creator::~Par2Creator(void)
 
   parpar.deinit();
 
-  vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
+  std::vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
   while (sourcefile != sourcefiles.end())
   {
     delete *sourcefile;
@@ -88,11 +88,11 @@ Par2Creator::~Par2Creator(void)
 
 Result Par2Creator::Process(
 			    const size_t memorylimit,
-			    const string &basepath,
+			    const std::string &basepath,
 			    const u32 nthreads,
 			    const u32 _filethreads,
-			    const string &parfilename,
-			    const vector<string> &_extrafiles,
+			    const std::string &parfilename,
+			    const std::vector<std::string> &_extrafiles,
 			    const u64 _blocksize,
 			    const u32 _firstblock,
 			    const Scheme _recoveryfilescheme,
@@ -106,7 +106,7 @@ Result Par2Creator::Process(
 
   // Get information from commandline
   blocksize = _blocksize;
-  const vector<string> extrafiles = _extrafiles;
+  const std::vector<std::string> extrafiles = _extrafiles;
   sourcefilecount = (u32)extrafiles.size();
   recoveryblockcount = _recoveryblockcount;
   recoveryfilecount = _recoveryfilecount;
@@ -134,7 +134,7 @@ Result Par2Creator::Process(
     return eLogicError;
 
   if (recoveryblockcount > 0 && noiselevel >= nlDebug)
-    sout << "[DEBUG] Process chunk size: " << chunksize << endl;
+    sout << "[DEBUG] Process chunk size: " << chunksize << std::endl;
 
   // Init ParPar backend
   if (!parpar.init(chunksize, {{&parparcpu, 0, (size_t)chunksize}}))
@@ -152,22 +152,22 @@ Result Par2Creator::Process(
   if (noiselevel > nlQuiet)
   {
     // Display information.
-    sout << "Block size: " << blocksize << endl;
-    sout << "Source file count: " << sourcefilecount << endl;
-    sout << "Source block count: " << sourceblockcount << endl;
-    sout << "Recovery block count: " << recoveryblockcount << endl;
-    sout << "Recovery file count: " << recoveryfilecount << endl;
+    sout << "Block size: " << blocksize << std::endl;
+    sout << "Source file count: " << sourcefilecount << std::endl;
+    sout << "Source block count: " << sourceblockcount << std::endl;
+    sout << "Recovery block count: " << recoveryblockcount << std::endl;
+    sout << "Recovery file count: " << recoveryfilecount << std::endl;
     if (noiselevel >= nlNoisy)
     {
-      sout << "Data hash method: " << hasherInput_methodName() << endl;
-      sout << "Multiply method: " << parparcpu.getMethodName() << endl;
+      sout << "Data hash method: " << hasherInput_methodName() << std::endl;
+      sout << "Multiply method: " << parparcpu.getMethodName() << std::endl;
       if (noiselevel >= nlDebug)
       {
-        sout << "[DEBUG] Compute tile size: " << parparcpu.getChunkLen() << endl;
-        sout << "[DEBUG] Compute block grouping: " << parparcpu.getInputBatchSize() << endl;
+        sout << "[DEBUG] Compute tile size: " << parparcpu.getChunkLen() << std::endl;
+        sout << "[DEBUG] Compute block grouping: " << parparcpu.getInputBatchSize() << std::endl;
       }
     }
-    sout << endl;
+    sout << std::endl;
   }
 
   // Open all of the source files, compute the Hashes and CRC values, and store
@@ -198,7 +198,7 @@ Result Par2Creator::Process(
       return eMemoryError;
 
     // Set output exponents
-    vector<u16> recoveryindices(recoveryblockcount);
+    std::vector<u16> recoveryindices(recoveryblockcount);
     for (u16 i = 0; i < recoveryblockcount; i++)
       recoveryindices[i] = i + firstrecoveryblock;
     if (!parpar.setRecoverySlices(recoveryindices))
@@ -213,7 +213,7 @@ Result Par2Creator::Process(
     while (blockoffset < blocksize) // Continue until the end of the block.
     {
       // Work out how much data to process this time.
-      size_t blocklength = (size_t)min((u64)chunksize, blocksize-blockoffset);
+      size_t blocklength = (size_t)std::min((u64)chunksize, blocksize-blockoffset);
       if (!parpar.setCurrentSliceSize(blocklength))
         return eMemoryError;
 
@@ -225,7 +225,7 @@ Result Par2Creator::Process(
     }
 
     if (noiselevel > nlQuiet)
-      sout << "Writing recovery packets" << endl;
+      sout << "Writing recovery packets" << std::endl;
 
     // Finish computation of the recovery packets and write the headers to disk.
     if (!WriteRecoveryPacketHeaders())
@@ -241,7 +241,7 @@ Result Par2Creator::Process(
     return eLogicError;
 
   if (noiselevel > nlQuiet)
-    sout << "Writing verification packets" << endl;
+    sout << "Writing verification packets" << std::endl;
 
   // Write all other critical packets to disk.
   if (!WriteCriticalPackets())
@@ -252,16 +252,16 @@ Result Par2Creator::Process(
     return eFileIOError;
 
   if (noiselevel > nlSilent)
-    sout << "Done" << endl;
+    sout << "Done" << std::endl;
 
   return eSuccess;
 }
 
 // Check basepath permission
-bool Par2Creator::CheckBasepath(const string &parfilename)
+bool Par2Creator::CheckBasepath(const std::string &parfilename)
 {
-  string checkfilename = parfilename + ".check.par2";
-  DiskFile *diskfile = new DiskFile(sout, serr);
+  std::string checkfilename = parfilename + ".check.par2";
+  std::unique_ptr<DiskFile> diskfile(new DiskFile(sout, serr, output_lock));
   size_t dummysize = 4096;
 
   if (!diskfile->Create(checkfilename, dummysize))
@@ -277,12 +277,12 @@ bool Par2Creator::CheckBasepath(const string &parfilename)
 
 // Compute block size from block count or vice versa depending on which was
 // specified on the command line
-bool Par2Creator::ComputeBlockCount(const vector<string> &extrafiles)
+bool Par2Creator::ComputeBlockCount(const std::vector<std::string> &extrafiles)
 {
   FileSizeCache filesize_cache;
 
   largestfilesize = 0;
-  for (vector<string>::const_iterator i=extrafiles.begin(); i!=extrafiles.end(); i++)
+  for (std::vector<std::string>::const_iterator i=extrafiles.begin(); i!=extrafiles.end(); i++)
   {
     u64 filesize = filesize_cache.get(*i);
     if (largestfilesize < filesize)
@@ -294,27 +294,27 @@ bool Par2Creator::ComputeBlockCount(const vector<string> &extrafiles)
 
   if (blocksize == 0)
   {
-    serr << "ERROR: Block size was zero!" << endl;
+    serr << "ERROR: Block size was zero!" << std::endl;
     return false;
   }
 
   if (blocksize % 4 != 0)
   {
-    serr << "ERROR: Block size was not a multiple of 4 bytes!" << endl;
+    serr << "ERROR: Block size was not a multiple of 4 bytes!" << std::endl;
     return false;
   }
 
 
   u64 count = 0;
 
-  for (vector<string>::const_iterator i=extrafiles.begin(); i!=extrafiles.end(); i++)
+  for (std::vector<std::string>::const_iterator i=extrafiles.begin(); i!=extrafiles.end(); i++)
   {
     count += (filesize_cache.get(*i) + blocksize-1) / blocksize;
   }
 
   if (count > 32768)
   {
-    serr << "Block size is too small. It would require " << count << "blocks." << endl;
+    serr << "Block size is too small. It would require " << count << "blocks." << std::endl;
     return false;
   }
 
@@ -338,7 +338,7 @@ bool Par2Creator::CalculateProcessBlockSize(size_t memorylimit)
   else
   {
     // We use intermediary buffers to transfer data with, so include those in the limit calculation
-    u32 blockoverhead = NUM_TRANSFER_BUFFERS + min((u32)NUM_PARPAR_BUFFERS*2, sourceblockcount+1);
+    u32 blockoverhead = NUM_TRANSFER_BUFFERS + std::min((u32)NUM_PARPAR_BUFFERS*2, sourceblockcount+1);
 
     // Would single pass processing use too much memory
     if (blocksize * (recoveryblockcount + blockoverhead) > memorylimit)
@@ -354,7 +354,7 @@ bool Par2Creator::CalculateProcessBlockSize(size_t memorylimit)
 
       deferhashcomputation = true;
     }
-    
+
     if (MAX_CHUNK_SIZE != 0 && chunksize > MAX_CHUNK_SIZE)
     {
       chunksize = MAX_CHUNK_SIZE;
@@ -368,40 +368,40 @@ bool Par2Creator::CalculateProcessBlockSize(size_t memorylimit)
 
 // Open all of the source files, compute the Hashes and CRC values, and store
 // the results in the file verification and file description packets.
-bool Par2Creator::OpenSourceFiles(const vector<string> &extrafiles, string basepath)
+bool Par2Creator::OpenSourceFiles(const std::vector<std::string> &extrafiles, std::string basepath)
 {
-  atomic<bool> openfailed(false);
-  atomic<u64> totalprogress(0);
+  std::atomic<bool> openfailed(false);
+  std::atomic<u64> totalprogress(0);
 
   //Total size of files for mt-progress line
   for (size_t i=0; i<extrafiles.size(); ++i)
     mttotalsize += DiskFile::GetFileSize(extrafiles[i]);
 
-  mutex output_lock, packet_lock;
-  foreach_parallel<string>(extrafiles, Par2Creator::GetFileThreads(), [&, this](const string& extrafile) {
-    if (openfailed.load(memory_order_relaxed)) return;
+  std::mutex packet_lock;
+  foreach_parallel<std::string>(extrafiles, Par2Creator::GetFileThreads(), [&, this](const std::string& extrafile) {
+    if (openfailed.load(std::memory_order_relaxed)) return;
     Par2CreatorSourceFile *sourcefile = new Par2CreatorSourceFile;
 
-    string name;
+    std::string name;
     DiskFile::SplitRelativeFilename(extrafile, basepath, name);
     if (noiselevel > nlSilent)
     {
-      lock_guard<mutex> lock(output_lock);
-      sout << "Opening: " << name << endl;
+      std::lock_guard<std::mutex> lock(output_lock);
+      sout << "Opening: " << name << std::endl;
     }
 
     // Open the source file and compute its Hashes and CRCs.
     if (!sourcefile->Open(noiselevel, sout, serr, extrafile, blocksize, deferhashcomputation, basepath, mttotalsize, totalprogress, output_lock))
     {
       delete sourcefile;
-      openfailed.store(true, memory_order_relaxed);
+      openfailed.store(true, std::memory_order_relaxed);
       return;
     }
 
     // Record the file verification and file description packets
     // in the critical packet list.
     {
-      lock_guard<mutex> lock(packet_lock);
+      std::lock_guard<std::mutex> lock(packet_lock);
       sourcefile->RecordCriticalPackets(criticalpackets);
       
       // Add the source file to the sourcefiles array.
@@ -411,7 +411,7 @@ bool Par2Creator::OpenSourceFiles(const vector<string> &extrafiles, string basep
     sourcefile->Close();
   });
 
-  if (openfailed.load(memory_order_relaxed))
+  if (openfailed.load(std::memory_order_relaxed))
     return false;
 
   return true;
@@ -446,9 +446,9 @@ bool Par2Creator::CreateSourceBlocks(void)
   // Allocate the array of source blocks
   sourceblocks.resize(sourceblockcount);
 
-  vector<DataBlock>::iterator sourceblock = sourceblocks.begin();
+  std::vector<DataBlock>::iterator sourceblock = sourceblocks.begin();
 
-  for (vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
+  for (std::vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
        sourcefile!= sourcefiles.end();
        sourcefile++)
   {
@@ -471,19 +471,19 @@ public:
     count = 0;
   }
 
-  string filename;
+  std::string filename;
   u32 exponent;
   u32 count;
 };
 
 // Create all of the output files and allocate all packets to appropriate file offsets.
-bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
+bool Par2Creator::InitialiseOutputFiles(const std::string &parfilename)
 {
   // Allocate the recovery packets
   recoverypackets.resize(recoveryblockcount);
 
   // Choose filenames and decide which recovery blocks to place in each file
-  vector<FileAllocation> fileallocations;
+  std::vector<FileAllocation> fileallocations;
   fileallocations.resize(recoveryfilecount+1); // One extra file with no recovery blocks
   {
     // Decide how many recovery blocks to place in each file
@@ -531,7 +531,7 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
           u32 blocks = recoveryblockcount;
           for (u32 filenumber=0; filenumber<recoveryfilecount; filenumber++)
           {
-            u32 number = min(lowblockcount, blocks);
+            u32 number = std::min(lowblockcount, blocks);
             fileallocations[filenumber].exponent = exponent;
             fileallocations[filenumber].count = number;
             exponent += number;
@@ -571,7 +571,7 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
           // Allocate exponentially at the bottom
           for (filenumber=0; filenumber<files; filenumber++)
           {
-            u32 number = min(count, blocks);
+            u32 number = std::min(count, blocks);
             fileallocations[filenumber].exponent = exponent;
             fileallocations[filenumber].count = number;
 
@@ -588,8 +588,8 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
     fileallocations[recoveryfilecount].exponent = exponent;
     fileallocations[recoveryfilecount].count = 0;
 
-    // Determine the format to use for filenames of recovery files
-    char filenameformat[_MAX_PATH];
+    // Determine digit widths for recovery filenames
+    u32 digitsLow = 1, digitsCount = 1;
     {
       u32 limitLow = 0;
       u32 limitCount = 0;
@@ -605,34 +605,46 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
         }
       }
 
-      u32 digitsLow = 1;
       for (u32 t=limitLow; t>=10; t/=10)
       {
         digitsLow++;
       }
 
-      u32 digitsCount = 1;
       for (u32 t=limitCount; t>=10; t/=10)
       {
         digitsCount++;
       }
-
-      sprintf(filenameformat, "%%s.vol%%0%dd+%%0%dd.par2", (int) digitsLow, (int) digitsCount);
     }
 
     // Set the filenames
     for (u32 filenumber=0; filenumber<recoveryfilecount; filenumber++)
     {
-      char filename[_MAX_PATH];
-      snprintf(filename, sizeof(filename), filenameformat, parfilename.c_str(), fileallocations[filenumber].exponent, fileallocations[filenumber].count);
-      fileallocations[filenumber].filename = filename;
+      std::ostringstream filename;
+      filename << parfilename
+               << ".vol" << std::setw(digitsLow) << std::setfill('0') << fileallocations[filenumber].exponent
+               << "+" << std::setw(digitsCount) << std::setfill('0') << fileallocations[filenumber].count
+               << ".par2";
+
+      if (filename.str().length() > _MAX_PATH)
+      {
+        serr << filename.str() << " pathlength is more than " << _MAX_PATH << "." << std::endl;
+        return false;
+      }
+      fileallocations[filenumber].filename = filename.str();
     }
-    fileallocations[recoveryfilecount].filename = parfilename + ".par2";
+
+    std::string mainpar = parfilename + ".par2";
+    if (mainpar.length() > _MAX_PATH)
+    {
+      serr << mainpar << " pathlength is more than " << _MAX_PATH << "." << std::endl;
+      return false;
+    }
+    fileallocations[recoveryfilecount].filename = mainpar;
   }
 
   // Allocate the recovery files
   {
-    recoveryfiles.resize(recoveryfilecount+1, DiskFile(sout, serr)); // pass default constructor.
+    recoveryfiles.resize(recoveryfilecount+1, DiskFile(sout, serr, output_lock)); // pass default constructor.
 
     // Sort critical packets, so we get consistency.
     criticalpackets.sort(CriticalPacket::CompareLess);
@@ -640,10 +652,10 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
     // Allocate packets to the output files
     {
       const MD5Hash &setid = mainpacket->SetId();
-      vector<RecoveryPacket>::iterator recoverypacket = recoverypackets.begin();
+      std::vector<RecoveryPacket>::iterator recoverypacket = recoverypackets.begin();
 
-      vector<DiskFile>::iterator recoveryfile = recoveryfiles.begin();
-      vector<FileAllocation>::iterator fileallocation = fileallocations.begin();
+      std::vector<DiskFile>::iterator recoveryfile = recoveryfiles.begin();
+      std::vector<FileAllocation>::iterator fileallocation = fileallocations.begin();
 
       // For each recovery file:
       while (recoveryfile != recoveryfiles.end())
@@ -657,7 +669,7 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
         if (count == 0)
         {
           // Write one set of critical packets
-          list<CriticalPacket*>::const_iterator nextCriticalPacket = criticalpackets.begin();
+          std::list<CriticalPacket*>::const_iterator nextCriticalPacket = criticalpackets.begin();
 
           while (nextCriticalPacket != criticalpackets.end())
           {
@@ -680,7 +692,7 @@ bool Par2Creator::InitialiseOutputFiles(const string &parfilename)
 
           // Get ready to iterate through the critical packets
           u64 packetCount = 0;
-          list<CriticalPacket*>::const_iterator nextCriticalPacket = criticalpackets.end();
+          std::list<CriticalPacket*>::const_iterator nextCriticalPacket = criticalpackets.end();
 
           // What is the first exponent
           u32 exponent = fileallocation->exponent;
@@ -738,7 +750,7 @@ bool Par2Creator::AllocateBuffers(void)
 
   if (transferbuffer == NULL)
   {
-    serr << "Could not allocate buffer memory." << endl;
+    serr << "Could not allocate buffer memory." << std::endl;
     return false;
   }
 
@@ -751,21 +763,21 @@ bool Par2Creator::ProcessData(u64 blockoffset, size_t blocklength)
   // If we have deferred computation of the file hash and block crc and hashes
   // sourcefile and sourceindex will be used to update them during
   // the main recovery block computation
-  vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
+  std::vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
   u32 sourceindex = 0;
 
-  vector<DataBlock>::iterator sourceblock;
+  std::vector<DataBlock>::iterator sourceblock;
   u32 inputblock;
 
   DiskFile *lastopenfile = NULL;
 
   // For tracking input buffer availability
-  future<void> bufferavail[NUM_TRANSFER_BUFFERS];
+  std::future<void> bufferavail[NUM_TRANSFER_BUFFERS];
   u32 bufferindex = NUM_TRANSFER_BUFFERS - 1;
   // Set all input buffers to available
   for (i32 i = 0; i < NUM_TRANSFER_BUFFERS; i++)
   {
-    promise<void> stub;
+    std::promise<void> stub;
     bufferavail[i] = stub.get_future();
     stub.set_value();
   }
@@ -826,7 +838,7 @@ bool Par2Creator::ProcessData(u64 blockoffset, size_t blocklength)
 
       if (oldfraction != newfraction)
       {
-        sout << "Processing: " << newfraction/10 << '.' << newfraction%10 << "%\r" << flush;
+        sout << "Processing: " << newfraction/10 << '.' << newfraction%10 << "%\r" << std::flush;
       }
     }
 
@@ -853,7 +865,7 @@ bool Par2Creator::ProcessData(u64 blockoffset, size_t blocklength)
   if (recoveryblockcount > 0)
   {
     // For output, we only need two transfer buffers
-    future<bool> outbufavail[2];
+    std::future<bool> outbufavail[2];
     // Prepare first output
     outbufavail[0] = parpar.getOutput(0, transferbuffer);
 
@@ -871,7 +883,7 @@ bool Par2Creator::ProcessData(u64 blockoffset, size_t blocklength)
       // Wait for current buffer to be available
       if (!outbufavail[outputblock & 1].get())
       {
-        serr << "Internal checksum failure in recovery packet " << recoverypackets[outputblock].Exponent() << endl;
+        serr << "Internal checksum failure in recovery packet " << recoverypackets[outputblock].Exponent() << std::endl;
         return false;
       }
       
@@ -883,7 +895,7 @@ bool Par2Creator::ProcessData(u64 blockoffset, size_t blocklength)
   }
 
   if (noiselevel > nlQuiet)
-    sout << "Wrote " << recoveryblockcount * blocklength << " bytes to disk" << endl;
+    sout << "Wrote " << recoveryblockcount * blocklength << " bytes to disk" << std::endl;
 
   return true;
 }
@@ -892,7 +904,7 @@ bool Par2Creator::ProcessData(u64 blockoffset, size_t blocklength)
 bool Par2Creator::WriteRecoveryPacketHeaders(void)
 {
   // For each recovery packet
-  for (vector<RecoveryPacket>::iterator recoverypacket = recoverypackets.begin();
+  for (std::vector<RecoveryPacket>::iterator recoverypacket = recoverypackets.begin();
        recoverypacket != recoverypackets.end();
        ++recoverypacket)
   {
@@ -910,7 +922,7 @@ bool Par2Creator::FinishFileHashComputation(void)
   if (deferhashcomputation)
   {
     // For each source file
-    vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
+    std::vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
 
     while (sourcefile != sourcefiles.end())
     {
@@ -929,7 +941,7 @@ bool Par2Creator::FinishCriticalPackets(void)
   // Get the setid from the main packet
   const MD5Hash &setid = mainpacket->SetId();
 
-  for (list<CriticalPacket*>::iterator criticalpacket=criticalpackets.begin();
+  for (std::list<CriticalPacket*>::iterator criticalpacket=criticalpackets.begin();
        criticalpacket!=criticalpackets.end();
        criticalpacket++)
   {
@@ -945,7 +957,7 @@ bool Par2Creator::FinishCriticalPackets(void)
 // Write all other critical packets to disk.
 bool Par2Creator::WriteCriticalPackets(void)
 {
-  list<CriticalPacketEntry>::const_iterator packetentry = criticalpacketentries.begin();
+  std::list<CriticalPacketEntry>::const_iterator packetentry = criticalpacketentries.begin();
 
   // For each critical packet
   while (packetentry != criticalpacketentries.end())
@@ -964,7 +976,7 @@ bool Par2Creator::WriteCriticalPackets(void)
 bool Par2Creator::CloseFiles(void)
 {
 //  // Close each source file.
-//  for (vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
+//  for (std::vector<Par2CreatorSourceFile*>::iterator sourcefile = sourcefiles.begin();
 //       sourcefile != sourcefiles.end();
 //       ++sourcefile)
 //  {
@@ -972,7 +984,7 @@ bool Par2Creator::CloseFiles(void)
 //  }
 
   // Close each recovery file.
-  for (vector<DiskFile>::iterator recoveryfile = recoveryfiles.begin();
+  for (std::vector<DiskFile>::iterator recoveryfile = recoveryfiles.begin();
        recoveryfile != recoveryfiles.end();
        ++recoveryfile)
   {
